From mboxrd@z Thu Jan 1 00:00:00 1970 Received: from va-1-114.ptr.blmpb.com (va-1-114.ptr.blmpb.com [209.127.230.114]) (using TLSv1.2 with cipher ECDHE-RSA-AES128-GCM-SHA256 (128/128 bits)) (No client certificate requested) by smtp.subspace.kernel.org (Postfix) with ESMTPS id BCBB83F9F46 for ; Wed, 5 Aug 2026 09:49:50 +0000 (UTC) Authentication-Results: smtp.subspace.kernel.org; arc=none smtp.client-ip=209.127.230.114 ARC-Seal:i=1; a=rsa-sha256; d=subspace.kernel.org; s=arc-20240116; t=1785923393; cv=none; b=kRgjtlH9GO1welspW3HDSe5x0M/EI9XjSh2uYt6/u9U+qfNWJCeb2FwFi3+fNVQEP8OKT3t8yx/Uzi6KbET4bZO8i3ouvAgUO3iJt+w02QtK/t3dFd+4Q7F4sBdf/0JPlMKPQ0fpYsqPvdcQtB7QbitOPu/FrO9tjzQ/o2VxCIQ= ARC-Message-Signature:i=1; a=rsa-sha256; d=subspace.kernel.org; s=arc-20240116; t=1785923393; c=relaxed/simple; bh=kdm9JLDkzfeR7QzsuL8awd/xo9HMEeVRB2f+mQA1wKM=; h=Message-Id:Content-Type:References:To:Cc:From:Subject: Mime-Version:In-Reply-To:Date; b=mrediHW8OuwliVZrxTPNa7OVeNmfc7x6Kx8VpscuYj0j6tWnGdFgMtItvPKefqkvSMtDjOw7ZGOrgjWLWbHk0tj6B6r1J8MhKAlYpLsAqKf8OHTIXzRryzLrg7pnc+hcYoop7oaEmKQ5QF4GRY6Jgq9LsbZFdf48nF7spElAjdE= ARC-Authentication-Results:i=1; smtp.subspace.kernel.org; dmarc=pass (p=quarantine dis=none) header.from=bytedance.com; spf=pass smtp.mailfrom=bytedance.com; dkim=pass (2048-bit key) header.d=bytedance.com header.i=@bytedance.com header.b=SapNL7JM; arc=none smtp.client-ip=209.127.230.114 Authentication-Results: smtp.subspace.kernel.org; dmarc=pass (p=quarantine dis=none) header.from=bytedance.com Authentication-Results: smtp.subspace.kernel.org; spf=pass smtp.mailfrom=bytedance.com Authentication-Results: smtp.subspace.kernel.org; dkim=pass (2048-bit key) header.d=bytedance.com header.i=@bytedance.com header.b="SapNL7JM" DKIM-Signature: v=1; a=rsa-sha256; q=dns/txt; c=relaxed/relaxed; s=2212171451; d=bytedance.com; t=1785923386; h=from:subject: mime-version:from:date:message-id:subject:to:cc:reply-to:content-type: mime-version:in-reply-to:message-id; bh=Y/uAgkm9aok/nQAEqWTWVKcO/AScdnJJ1CYyygt77ao=; b=SapNL7JMPb1FOlhJ98JpcCYff/SGexhYFrVyyr9IdxPtMp08AiOuSpbIoobO1bCjcix+l4 x0x3gG5Nxlu5wL8jV9lPCk8DGnak+l4AGLb4M13ka3lfnX1Z737gr9lbPvbsPNxTXn+lEp +mV3eUrEw7j1OBQ3STL558KJMn2VB1D8DQcAMexAsfL+OKEKh3kaiYcSvl20Ra52zMKwCq tdfIX3z4DUqQlxVyq3SKqCbPduETEWvNn4LzXJGoWhC4MWNbde/ZYRC2AkqiIwzrNY0UiC AKnpsZQhj5jmhhoukLV6iZMPAhkZX3Xu/CwlT7w944+dyxQeJuRJFI7cp7FEUA== Message-Id: <7ce88e5a-8b96-4508-91b1-b72a589e6ac4@bytedance.com> Content-Type: text/plain; charset=UTF-8 References: <20260803070929.86075-1-lizhe.67@bytedance.com> <20260803144014.e2d4ebb83e9471b695f6290d@linux-foundation.org> To: "Andrew Morton" Cc: , , , , , , , , , , , , , , , From: "Li Zhe" Subject: Re: [PATCH v9 0/8] mm: optimize zone-device memmap initialization Precedence: bulk X-Mailing-List: linux-kernel@vger.kernel.org List-Id: List-Subscribe: List-Unsubscribe: Mime-Version: 1.0 X-Lms-Return-Path: In-Reply-To: <20260803144014.e2d4ebb83e9471b695f6290d@linux-foundation.org> X-Original-From: Li Zhe Date: Wed, 5 Aug 2026 17:49:22 +0800 User-Agent: Mozilla Thunderbird Content-Transfer-Encoding: 7bit On 8/4/26 5:40 AM, Andrew Morton wrote: > On Mon, 3 Aug 2026 15:09:21 +0800 "Li Zhe" wrote: > >> Test procedure: >> Rebind the nd_pmem and dax_pmem drivers 30 times and collect the memmap >> initialization time from the pr_debug() output of >> memmap_init_zone_device(). >> >> Base(v7.2-rc1): >> Average of nd_pmem rebinds: 244.28 ms >> Average of dax_pmem rebinds: 273.31 ms >> >> With this series applied: >> Average of nd_pmem rebinds: 96.79 ms >> Average of dax_pmem rebinds: 119.04 ms >> >> This reduces the average memmap initialization time measured during >> rebind by about 60.4% for nd_pmem and 56.4% for dax_pmem. > Well that's nice. > > Review is partial and it's late in the cycle so I'd prefer to schedule > this for the next -rc cycle. > > AI review might have found a couple of things, please check? > https://sashiko.dev/#/patchset/20260803070929.86075-1-lizhe.67@bytedance.com Thanks. I checked the Sashiko comments. The reported items are the same points that were discussed in the previous v7/v8 reviews. v9 already folds the related explanation into patch 7, so I do not plan any additional code change for these items. Thanks, Zhe